﻿using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraEditors.Repository;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 저장소 항목 진행바
        /// </summary>
        private RepositoryItemProgressBar repositoryItemProgressBar = new RepositoryItemProgressBar();
        
        /// <summary>
        /// 저장소 항목 스핀 에디터
        /// </summary>
        private RepositoryItemSpinEdit repositoryItemSpinEdit = new RepositoryItemSpinEdit();

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridControl.RepositoryItems.AddRange
            (
                new RepositoryItem[]
                {
                    this.repositoryItemProgressBar,
                    this.repositoryItemSpinEdit
                }
            );

            this.gridView.InitializeView
            (
                true,                           // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                true                            // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.ProductsTableAdapter().GetData();
     
            this.gridView.Columns["UnitPrice"].ColumnEdit = this.repositoryItemProgressBar;

            this.gridView.BestFitColumns();

            this.gridView.CustomRowCellEditForEditing += gridView_CustomRowCellEditForEditing;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 행/셀 편집시 커스텀 처리하기 - gridView_CustomRowCellEditForEditing(sender, e)

        /// <summary>
        /// 그리드 뷰 행/셀 편집시 커스텀 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_CustomRowCellEditForEditing(object sender, CustomRowCellEditEventArgs e)
        {
            if(e.Column.FieldName == "UnitPrice")
            {
                e.RepositoryItem = this.repositoryItemSpinEdit;
            }
        }

        #endregion
    }
}